@@ -34,77 +34,97 @@ private Q_SLOTS:
         airport.setName(QStringLiteral("Berlin Tegel"));
         {
             auto ap2 = airport;
-            QCOMPARE(ap2.name(), QLatin1String("Berlin Tegel"));
+            QCOMPARE(ap2.name(), QLatin1StringView("Berlin Tegel"));
             ap2.setIataCode(QStringLiteral("TXL"));
             QVERIFY(airport.iataCode().isEmpty());
         }
         Place place = airport; // assignment to base class works, but cannot be reversed
-        QCOMPARE(place.name(), QLatin1String("Berlin Tegel"));
+        QCOMPARE(place.name(), QLatin1StringView("Berlin Tegel"));
         place.setName(QStringLiteral("London Heathrow")); // changing a value degenerated to its base class will detach but not slice
-        QCOMPARE(place.name(), QLatin1String("London Heathrow"));
-        QCOMPARE(JsonLdDocument::readProperty(place, "className").toString(), QLatin1String("Place")); // className is not polymorphic
+        QCOMPARE(place.name(), QLatin1StringView("London Heathrow"));
+        QCOMPARE(JsonLdDocument::readProperty(place, "className").toString(),
+                 QLatin1StringView("Place")); // className is not polymorphic
 
         QVERIFY(!airport.geo().isValid());
-        QCOMPARE(JsonLdDocument::readProperty(airport, "className").toString(), QLatin1String("Airport"));
-        QCOMPARE(JsonLdDocument::readProperty(airport, "name").toString(), QLatin1String("Berlin Tegel"));
+        QCOMPARE(JsonLdDocument::readProperty(airport, "className").toString(),
+                 QLatin1StringView("Airport"));
+        QCOMPARE(JsonLdDocument::readProperty(airport, "name").toString(),
+                 QLatin1StringView("Berlin Tegel"));
 
         // detach on base properties must not slice
         FlightReservation res;
-        QCOMPARE(JsonLdDocument::readProperty(res, "className").toString(), QLatin1String("FlightReservation"));
+        QCOMPARE(JsonLdDocument::readProperty(res, "className").toString(),
+                 QLatin1StringView("FlightReservation"));
         res.setAirplaneSeat(QStringLiteral("10E"));
-        QCOMPARE(res.airplaneSeat(), QLatin1String("10E"));
+        QCOMPARE(res.airplaneSeat(), QLatin1StringView("10E"));
         auto res2 = res;
-        QCOMPARE(res2.airplaneSeat(), QLatin1String("10E"));
+        QCOMPARE(res2.airplaneSeat(), QLatin1StringView("10E"));
         res2.setReservationNumber(QStringLiteral("XXX007"));
-        QCOMPARE(res2.airplaneSeat(), QLatin1String("10E"));
+        QCOMPARE(res2.airplaneSeat(), QLatin1StringView("10E"));
 
         // changing default-created properties should not leak
         Flight flight;
-        QCOMPARE(JsonLdDocument::readProperty(flight, "className").toString(), QLatin1String("Flight"));
+        QCOMPARE(JsonLdDocument::readProperty(flight, "className").toString(),
+                 QLatin1StringView("Flight"));
         QVariant v = flight;
         QVERIFY(v.canConvert<Flight>());
         JsonLdDocument::writeProperty(v, "departureAirport", airport);
-        QCOMPARE(v.value<Flight>().departureAirport().name(), QLatin1String("Berlin Tegel"));
+        QCOMPARE(v.value<Flight>().departureAirport().name(),
+                 QLatin1StringView("Berlin Tegel"));
 
         // make sure all meta types are generated
         TrainTrip tt;
-        QCOMPARE(JsonLdDocument::readProperty(tt, "className").toString(), QLatin1String("TrainTrip"));
+        QCOMPARE(JsonLdDocument::readProperty(tt, "className").toString(),
+                 QLatin1StringView("TrainTrip"));
         BusTrip bus;
-        QCOMPARE(JsonLdDocument::readProperty(bus, "className").toString(), QLatin1String("BusTrip"));
+        QCOMPARE(JsonLdDocument::readProperty(bus, "className").toString(),
+                 QLatin1StringView("BusTrip"));
 
         Ticket ticket;
-        QCOMPARE(JsonLdDocument::readProperty(ticket.ticketedSeat(), "className").toString(), QLatin1String("Seat"));
+        QCOMPARE(
+            JsonLdDocument::readProperty(ticket.ticketedSeat(), "className")
+                .toString(),
+            QLatin1StringView("Seat"));
 
         Organization org;
         org.setName(QStringLiteral("JR East"));
         org.setEmail(QStringLiteral("nowhere@nowhere.com"));
         org.setTelephone(QStringLiteral("+55-1234-345"));
         org.setUrl(QUrl(QStringLiteral("http://www.jreast.co.jp/e/")));
-        QCOMPARE(JsonLdDocument::readProperty(org, "className").toString(), QLatin1String("Organization"));
-        QCOMPARE(org.name(), QLatin1String("JR East"));
-        QCOMPARE(org.email(), QLatin1String("nowhere@nowhere.com"));
-        QCOMPARE(org.telephone(), QLatin1String("+55-1234-345"));
-        QCOMPARE(org.url(), QUrl(QLatin1String("http://www.jreast.co.jp/e/")));
+        QCOMPARE(JsonLdDocument::readProperty(org, "className").toString(),
+                 QLatin1StringView("Organization"));
+        QCOMPARE(org.name(), QLatin1StringView("JR East"));
+        QCOMPARE(org.email(), QLatin1StringView("nowhere@nowhere.com"));
+        QCOMPARE(org.telephone(), QLatin1StringView("+55-1234-345"));
+        QCOMPARE(org.url(),
+                 QUrl(QLatin1StringView("http://www.jreast.co.jp/e/")));
 
         tt.setProvider(org);
         res.setProvider(org);
         bus.setProvider(org);
-        QCOMPARE(tt.provider().name(), QLatin1String("JR East"));
-        QCOMPARE(tt.provider().email(), QLatin1String("nowhere@nowhere.com"));
-        QCOMPARE(res.provider().name(), QLatin1String("JR East"));
-        QCOMPARE(res.provider().email(), QLatin1String("nowhere@nowhere.com"));
-        QCOMPARE(bus.provider().name(), QLatin1String("JR East"));
-        QCOMPARE(bus.provider().email(), QLatin1String("nowhere@nowhere.com"));
+        QCOMPARE(tt.provider().name(), QLatin1StringView("JR East"));
+        QCOMPARE(tt.provider().email(),
+                 QLatin1StringView("nowhere@nowhere.com"));
+        QCOMPARE(res.provider().name(), QLatin1StringView("JR East"));
+        QCOMPARE(res.provider().email(),
+                 QLatin1StringView("nowhere@nowhere.com"));
+        QCOMPARE(bus.provider().name(), QLatin1StringView("JR East"));
+        QCOMPARE(bus.provider().email(),
+                 QLatin1StringView("nowhere@nowhere.com"));
 
         Airline airline;
         airline.setIataCode(QStringLiteral("LH"));
         flight.setAirline(airline);
-        QCOMPARE(flight.airline().iataCode(), QLatin1String("LH"));
+        QCOMPARE(flight.airline().iataCode(), QLatin1StringView("LH"));
         {
             const auto flight2 = flight;
-            QCOMPARE(flight2.airline().iataCode(), QLatin1String("LH"));
-            QCOMPARE(JsonLdDocument::readProperty(flight.airline(), "className").toString(), QLatin1String("Airline"));
-            QCOMPARE(JsonLdDocument::readProperty(flight.airline(), "iataCode").toString(), QLatin1String("LH"));
+            QCOMPARE(flight2.airline().iataCode(), QLatin1StringView("LH"));
+            QCOMPARE(JsonLdDocument::readProperty(flight.airline(), "className")
+                         .toString(),
+                     QLatin1StringView("Airline"));
+            QCOMPARE(JsonLdDocument::readProperty(flight.airline(), "iataCode")
+                         .toString(),
+                     QLatin1StringView("LH"));
         }
     }
 
@@ -144,7 +164,7 @@ private Q_SLOTS:
         QVERIFY(!JsonLd::canConvert<Airport>(p));
 
         p = JsonLd::convert<Place>(a);
-        QCOMPARE(p.name(), QLatin1String("Berlin Tegel"));
+        QCOMPARE(p.name(), QLatin1StringView("Berlin Tegel"));
     }
 
     void testCompare()
