@@ -33,12 +33,12 @@ namespace KItinerary {
 
 #define UPER_ELEMENT(Type, Name) \
 public: \
-    Type Name = {}; \
+    Type Name = {}; /* NOLINT misc-non-private-member-variables-in-classes */ \
     Q_PROPERTY(Type Name MEMBER Name CONSTANT)
 
 #define UPER_ELEMENT_OPTIONAL(Type, Name) \
 public: \
-    Type Name = {}; \
+    Type Name = {}; /* NOLINT misc-non-private-member-variables-in-classes */ \
     Q_PROPERTY(Type Name MEMBER Name CONSTANT) \
     Q_PROPERTY(bool Name ## IsSet READ Name ## IsSet) \
 private: \
@@ -46,17 +46,17 @@ private: \
     static constexpr auto _uper_optional_counter(detail::num<decltype(_uper_optional_counter(detail::num<>()))::value + 1> n) \
         -> decltype(n) { return {}; } \
 public: \
-    inline bool Name ## IsSet() const { return m_optionals[m_optionals.size() - _uper_ ## Name ## OptionalIndex - 1]; }
+    [[nodiscard]] inline bool Name ## IsSet() const { return m_optionals[m_optionals.size() - _uper_ ## Name ## OptionalIndex - 1]; }
 
 #define UPER_ELEMENT_DEFAULT(Type, Name, DefaultValue) \
 public: \
-    Type Name = DefaultValue; \
+    Type Name = DefaultValue; /* NOLINT misc-non-private-member-variables-in-classes */ \
     Q_PROPERTY(Type Name MEMBER Name CONSTANT) \
 private: \
     static constexpr int _uper_ ## Name ## OptionalIndex = decltype(_uper_optional_counter(detail::num<>()))::value; \
     static constexpr auto _uper_optional_counter(detail::num<decltype(_uper_optional_counter(detail::num<>()))::value + 1> n) \
         -> decltype(n) { return {}; } \
-    inline bool Name ## IsSet() const { return m_optionals[m_optionals.size() - _uper_ ## Name ## OptionalIndex - 1]; }
+    [[nodiscard]] inline bool Name ## IsSet() const { return m_optionals[m_optionals.size() - _uper_ ## Name ## OptionalIndex - 1]; }
 }
 
 #define UPER_GADGET_FINALIZE \
