@@ -6,28 +6,36 @@
 
 #include "iatabcbpparser.h"
 #include "logging.h"
+#include "reservationconverter.h"
+
 #include "iata/iatabcbp.h"
 
+#include "knowledgedb/airportdb.h"
+#include "knowledgedb/trainstationdb.h"
+
 #include <KItinerary/Flight>
+#include <KItinerary/JsonLdDocument>
 #include <KItinerary/Organization>
 #include <KItinerary/Person>
 #include <KItinerary/Place>
 #include <KItinerary/Reservation>
 #include <KItinerary/Ticket>
+#include <KItinerary/TrainTrip>
 
+#include <QJsonObject>
 #include <QVariant>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KItinerary;
 
-static QString stripLeadingZeros(const QString &s)
+[[nodiscard]] static QString stripLeadingZeros(const QString &s)
 {
-    const auto it = std::find_if(s.begin(), s.end(), [](const QChar &c) { return c != QLatin1Char('0'); });
+    const auto it = std::find_if(s.begin(), s.end(), [](const QChar &c) { return c != '0'_L1; });
     const auto d = std::distance(s.begin(), it);
     return s.mid(d);
 }
 
-QList<QVariant> IataBcbpParser::parse(const QString &message,
-                                      const QDateTime &externalIssueDate) {
+QList<QVariant> IataBcbpParser::parse(const QString &message, const QDateTime &externalIssueDate) {
     IataBcbp bcbp(message);
     if (!bcbp.isValid()) {
         return {};
@@ -46,15 +54,43 @@ QList<QVariant> IataBcbpParser::parse(const QString &message,
         return {};
     }
 
-    if (std::all_of(documentNumber.begin(), documentNumber.end(), [](QChar c) { return c == QLatin1Char('0'); })) {
+    if (std::all_of(documentNumber.begin(), documentNumber.end(), [](QChar c) { return c == '0'_L1; })) {
         return {};
     }
 
-    return airlineNumericCode + QLatin1Char(' ') + documentNumber;
+    return airlineNumericCode + ' '_L1 + documentNumber;
 }
 
-QList<QVariant> IataBcbpParser::parse(const IataBcbp &bcbp,
-                                      const QDateTime &contextDate) {
+// check if one of the airports is actually a train station, and convert the reservation accordingly
+[[nodiscard]] QVariant checkModeOfTransport(FlightReservation &&res)
+{
+    const auto flight = res.reservationFor().value<Flight>();
+    const auto from = KnowledgeDb::IataCode(flight.departureAirport().iataCode());
+    const auto to = KnowledgeDb::IataCode(flight.arrivalAirport().iataCode());
+
+    if (KnowledgeDb::coordinateForAirport(from).isValid() && KnowledgeDb::coordinateForAirport(to).isValid()) {
+        return res;
+    }
+    if (KnowledgeDb::stationForIataCode(from).coordinate.isValid() || KnowledgeDb::stationForIataCode(to).coordinate.isValid()) {
+        auto trainRes = JsonLdDocument::fromJsonSingular(ReservationConverter::flightToTrain(JsonLdDocument::toJson(res))).value<TrainReservation>();
+        auto trip = trainRes.reservationFor().value<TrainTrip>();
+        {
+            auto station = trip.departureStation();
+            station.setName(from.toString());
+            trip.setDepartureStation(station);
+        }
+        {
+            auto station = trip.arrivalStation();
+            station.setName(to.toString());
+            trip.setArrivalStation(station);
+        }
+        trainRes.setReservationFor(std::move(trip));
+        return trainRes;
+    }
+    return res;
+}
+
+QList<QVariant> IataBcbpParser::parse(const IataBcbp &bcbp, const QDateTime &contextDate) {
     const auto count = bcbp.uniqueMandatorySection().numberOfLegs();
     const auto issueDate = bcbp.uniqueConditionalSection().dateOfIssue(contextDate);
 
@@ -64,7 +100,7 @@ QList<QVariant> IataBcbpParser::parse(const IataBcbp &bcbp,
     Person person;
     {
         const auto fullName = bcbp.uniqueMandatorySection().passengerName();
-        const auto idx = fullName.indexOf(QLatin1Char('/'));
+        const auto idx = fullName.indexOf('/'_L1);
         if (idx > 0 && idx < fullName.size() - 1) {
             person.setFamilyName(fullName.left(idx));
             person.setGivenName(fullName.mid(idx + 1));
@@ -99,7 +135,7 @@ QList<QVariant> IataBcbpParser::parse(const IataBcbp &bcbp,
         res.setUnderName(person);
 
         Ticket ticket;
-        ticket.setTicketToken(QStringLiteral("aztecCode:") + bcbp.rawData());
+        ticket.setTicketToken("aztecCode:"_L1 + bcbp.rawData());
         const auto rcs = bcbp.repeatedConditionalSection(i);
         ticket.setTicketNumber(ticketNumber(rcs.airlineNumericCode(), rcs.documentNumber()));
         res.setReservedTicket(ticket);
@@ -112,7 +148,7 @@ QList<QVariant> IataBcbpParser::parse(const IataBcbp &bcbp,
             res.setProgramMembershipUsed(program);
         }
 
-        result.push_back(std::move(res));
+        result.push_back(checkModeOfTransport(std::move(res)));
     }
 
     return result;
