@@ -106,6 +106,7 @@ QJSValue JsApi::JsonLd::newBusReservation() const
     auto resFor = newObject(QStringLiteral("BusTrip"));
     resFor.setProperty(QStringLiteral("departureBusStop"), dep);
     resFor.setProperty(QStringLiteral("arrivalBusStop"), arr);
+    resFor.setProperty(QStringLiteral("provider"), newObject(QStringLiteral("Organization")));
 
     auto res = newObject(QStringLiteral("BusReservation"));
     res.setProperty(QStringLiteral("reservationFor"), resFor);
@@ -336,7 +337,7 @@ QJSValue JsApi::JsonLd::toGeoCoordinates(const QString &mapUrl)
     QUrl url(mapUrl);
     if (url.host().contains(QLatin1StringView("google"))) {
       QRegularExpression regExp(
-          QStringLiteral("[/=](-?\\d+\\.\\d+),(-?\\d+\\.\\d+)"));
+          QStringLiteral("[/=@](-?\\d+\\.\\d+),(-?\\d+\\.\\d+)"));
       auto match = regExp.match(url.path());
       if (!match.hasMatch()) {
         match = regExp.match(url.query());
