@@ -7,10 +7,9 @@
 #ifndef KITINERARY_AIRPORTNAMETOKENIZER_H
 #define KITINERARY_AIRPORTNAMETOKENIZER_H
 
+#include <QStringList>
 #include <QStringView>
 
-class QStringList;
-
 namespace KItinerary {
 
 /** Split airport names into the tokens used by the airport database. */
