@@ -6,6 +6,7 @@
 
 #include "pkpassdocumentprocessor.h"
 
+#include <KItinerary/DocumentUtil>
 #include <KItinerary/Event>
 #include <KItinerary/ExtractorDocumentNodeFactory>
 #include <KItinerary/ExtractorEngine>
@@ -15,11 +16,13 @@
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/Reservation>
 #include <KItinerary/Ticket>
+#include <KItinerary/TrainTrip>
 
-#include <knowledgedb/airportdb.h>
-#include <text/nameoptimizer_p.h>
-#include <text/pricefinder_p.h>
-#include <text/timefinder_p.h>
+#include "reservationconverter.h"
+#include "knowledgedb/airportdb.h"
+#include "text/nameoptimizer_p.h"
+#include "text/pricefinder_p.h"
+#include "text/timefinder_p.h"
 
 #include <KPkPass/Barcode>
 #include <KPkPass/BoardingPass>
@@ -33,13 +36,15 @@
 #include <QTimeZone>
 #include <QVariant>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KItinerary;
 
 Q_DECLARE_METATYPE(KItinerary::Internal::OwnedPtr<KPkPass::Pass>)
 
 bool PkPassDocumentProcessor::canHandleData(const QByteArray &encodedData, QStringView fileName) const
 {
-    return encodedData.startsWith("PK\x03\x04") || fileName.endsWith(QLatin1String(".pkpass"), Qt::CaseInsensitive);
+  return encodedData.startsWith("PK\x03\x04") ||
+         fileName.endsWith(QLatin1StringView(".pkpass"), Qt::CaseInsensitive);
 }
 
 ExtractorDocumentNode PkPassDocumentProcessor::createNodeFromData(const QByteArray &encodedData) const
@@ -80,8 +85,18 @@ void PkPassDocumentProcessor::expandNode(ExtractorDocumentNode &node, const Extr
         return;
     }
 
-    auto child = engine->documentNodeFactory()->createNode(barcodes[0].message().toUtf8());
-    node.appendChild(child);
+    for (const auto &barcode : barcodes) {
+        // try to recover binary barcode content (which wont survive a JSON/QString roundtrip)
+        const auto msg = barcode.message();
+        auto data = msg.toUtf8();
+        if (std::any_of(msg.begin(), msg.end(), [](QChar c) { return c.isNonCharacter() || c.isNull() || !c.isPrint(); })) {
+            if (barcode.messageEncoding().compare("iso-8859-1"_L1, Qt::CaseInsensitive) == 0) {
+                data = msg.toLatin1();
+            }
+        }
+        auto child = engine->documentNodeFactory()->createNode(data);
+        node.appendChild(child);
+    }
 }
 
 void PkPassDocumentProcessor::destroyNode(ExtractorDocumentNode &node) const
@@ -134,7 +149,7 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
     const auto fields = pass->fields();
     for (const auto &field : fields) {
         // boarding time
-        if (!flight.boardingTime().isValid() && field.key().contains(QLatin1String("boarding"), Qt::CaseInsensitive)) {
+        if (!flight.boardingTime().isValid() && field.key().contains("boarding"_L1, Qt::CaseInsensitive)) {
             const auto time = timeFinder.findSingularTime(field.value().toString());
             if (time.isValid()) {
                 // this misses date, but the postprocessor will fill that in
@@ -143,7 +158,7 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
             }
         }
         // departure gate
-        if (flight.departureGate().isEmpty() && field.key().contains(QLatin1String("gate"), Qt::CaseInsensitive)) {
+        if (flight.departureGate().isEmpty() && field.key().contains("gate"_L1, Qt::CaseInsensitive)) {
             const auto gateStr = field.value().toString();
             if (isPlausibleGate(gateStr)) {
                 flight.setDepartureGate(gateStr);
@@ -151,7 +166,7 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
             }
         }
         // departure time
-        if (!flight.departureTime().isValid() && field.key().contains(QLatin1String("departure"), Qt::CaseInsensitive)) {
+        if (!flight.departureTime().isValid() && field.key().contains("departure"_L1, Qt::CaseInsensitive)) {
             const auto time = timeFinder.findSingularTime(field.value().toString());
             if (time.isValid()) {
                 // this misses date, but the postprocessor will fill that in
@@ -160,11 +175,11 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
             }
         }
 
-        if (field.key().contains(QLatin1String("terminal"), Qt::CaseInsensitive)) {
+        if (field.key().contains("terminal"_L1, Qt::CaseInsensitive)) {
             if (departureTerminal.isNull()) {
                 departureTerminal = field.value().toString();
             } else {
-                departureTerminal = QStringLiteral(""); // empty but not null, marking multiple terminal candidates
+                departureTerminal = u""_s; // empty but not null, marking multiple terminal candidates
             }
         }
     }
@@ -234,6 +249,73 @@ static Flight extractBoardingPass(KPkPass::Pass *pass, Flight flight)
     return flight;
 }
 
+[[nodiscard]] static TrainReservation extractTrainTicket(KPkPass::Pass *pass, TrainReservation res)
+{
+    auto trip = res.reservationFor().value<TrainTrip>();
+    auto ticket = res.reservedTicket().value<Ticket>();
+
+    TimeFinder timeFinder;
+    const auto fields = pass->fields();
+    for (const auto &field : fields) {
+        // departure platform
+        if (trip.departurePlatform().isEmpty() && field.key().contains("track"_L1, Qt::CaseInsensitive)) {
+            const auto platformStr = field.value().toString();
+            if (isPlausibleGate(platformStr)) {
+                trip.setDeparturePlatform(platformStr);
+                continue;
+            }
+        }
+        // departure time
+        if (!trip.departureTime().isValid() && field.key().contains("departure"_L1, Qt::CaseInsensitive)) {
+            const auto time = timeFinder.findSingularTime(field.value().toString());
+            if (time.isValid()) {
+                // this misses date, but the postprocessor will fill that in
+                trip.setDepartureTime(QDateTime(QDate(1, 1, 1), time));
+                continue;
+            }
+        }
+        // coach/seat
+        if (ticket.ticketedSeat().seatSection().isEmpty() && field.key().contains("coach"_L1, Qt::CaseInsensitive)) {
+            auto seat = ticket.ticketedSeat();
+            seat.setSeatSection(field.value().toString());
+            ticket.setTicketedSeat(seat);
+        }
+        if (ticket.ticketedSeat().seatNumber().isEmpty() && field.key().contains("seat"_L1, Qt::CaseInsensitive)) {
+            auto seat = ticket.ticketedSeat();
+            seat.setSeatNumber(field.value().toString());
+            ticket.setTicketedSeat(seat);
+        }
+    }
+
+    // "relevantDate" is the best guess for the departure time if we didn't find an explicit field for it
+    if (pass->relevantDate().isValid() && !trip.departureTime().isValid()) {
+        // TODO try to recover timezone?
+        trip.setDepartureTime(pass->relevantDate());
+    }
+
+    // location is the best guess for the departure station geo coordinates
+    auto depStation = trip.departureStation();
+    auto depGeo = depStation.geo();
+    if (pass->locations().size() == 1 && !depGeo.isValid()) {
+        const auto loc = pass->locations().at(0);
+        depGeo.setLatitude((float)loc.latitude());
+        depGeo.setLongitude((float)loc.longitude());
+        depStation.setGeo(depGeo);
+        trip.setDepartureStation(depStation);
+    }
+
+    // organizationName is the best guess for airline name
+    auto provider = trip.provider();
+    if (provider.name().isEmpty()) {
+        provider.setName(pass->organizationName());
+        trip.setProvider(provider);
+    }
+
+    res.setReservationFor(trip);
+    res.setReservedTicket(ticket);
+    return res;
+}
+
 static void extractEventTicketPass(KPkPass::Pass *pass, EventReservation &eventRes)
 {
     auto event = eventRes.reservationFor().value<Event>();
@@ -298,24 +380,30 @@ void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_un
     if (auto boardingPass = qobject_cast<KPkPass::BoardingPass*>(pass)) {
         switch (boardingPass->transitType()) {
             case KPkPass::BoardingPass::Air:
-                result.insert(QStringLiteral("@type"), QLatin1String("FlightReservation"));
+                result.insert("@type"_L1, "FlightReservation"_L1);
                 break;
             case KPkPass::BoardingPass::Train:
-                result.insert(QStringLiteral("@type"), QLatin1String("TrainReservation"));
+                result.insert("@type"_L1, "TrainReservation"_L1);
                 break;
             case KPkPass::BoardingPass::Bus:
-                result.insert(QStringLiteral("@type"), QLatin1String("BusReservation"));
+                result.insert("@type"_L1, "BusReservation"_L1);
                 break;
-            // TODO expand once we have test files for other types
-            default:
+            case KPkPass::BoardingPass::Boat:
+                result.insert("@type"_L1, "BoatReservation"_L1);
                 break;
+            case KPkPass::BoardingPass::Generic:
+                return;
         }
     } else {
         switch (pass->type()) {
+            case KPkPass::Pass::BoardingPass:
+                Q_UNREACHABLE(); // handled above
             case KPkPass::Pass::EventTicket:
-                result.insert(QStringLiteral("@type"), QLatin1String("EventReservation"));
+                result.insert("@type"_L1, "EventReservation"_L1);
                 break;
-            default:
+            case KPkPass::Pass::Coupon:
+            case KPkPass::Pass::StoreCard:
+            case KPkPass::Pass::Generic:
                 return;
         }
     }
@@ -325,23 +413,28 @@ void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_un
         const auto barcode = pass->barcodes().at(0);
         QString token;
         switch (barcode.format()) {
+            case KPkPass::Barcode::Invalid:
+                break;
             case KPkPass::Barcode::QR:
-                token += QLatin1String("qrCode:");
+                token = "qrCode:"_L1;
                 break;
             case KPkPass::Barcode::Aztec:
-                token += QLatin1String("aztecCode:");
-                break;
-            default:
+                token = "aztecCode:"_L1;
+              break;
+            case KPkPass::Barcode::PDF417:
+                token = "pdf417:"_L1;
                 break;
+            case KPkPass::Barcode::Code128:
+                token = "barcode128:"_L1;
         }
         token += barcode.message();
-        QJsonObject ticket = result.value(QLatin1String("reservedTicket")).toObject();
-        ticket.insert(QStringLiteral("@type"), QLatin1String("Ticket"));
-        ticket.insert(QStringLiteral("ticketToken"), token);
-        result.insert(QStringLiteral("reservedTicket"), ticket);
+        QJsonObject ticket = result.value("reservedTicket"_L1).toObject();
+        ticket.insert("@type"_L1, "Ticket"_L1);
+        ticket.insert("ticketToken"_L1, token);
+        result.insert("reservedTicket"_L1, ticket);
     }
 
-    // explicitly merge with the decoded barcode data, as this would other wise not match
+    // explicitly merge with the decoded barcode data, as this would otherwise not match
     auto res = JsonLdDocument::fromJsonSingular(result);
     if (JsonLd::isA<FlightReservation>(res)) {
         // if this doesn't contain a single IATA BCBP we wont be able to get sufficient information out of this
@@ -350,6 +443,20 @@ void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_un
         }
         res = JsonLdDocument::apply(node.childNodes()[0].result().result().at(0), res).value<FlightReservation>();
     }
+    if (JsonLd::isA<TrainReservation>(res)) {
+        // if this is a IATA BCBP the child node extractor will have classified this as a flight
+        if (!node.childNodes().empty() && node.childNodes()[0].result().size() > 1) {
+            return;
+        }
+        if (!node.result().isEmpty()) {
+            if (JsonLd::isA<FlightReservation>(node.childNodes()[0].result().result().at(0))) {
+                const auto flightRes = node.childNodes()[0].result().jsonLdResult().at(0).toObject();
+                res = JsonLdDocument::apply(JsonLdDocument::fromJsonSingular(ReservationConverter::flightToTrain(flightRes)), res).value<TrainReservation>();
+            } else {
+                res = JsonLdDocument::apply(node.childNodes()[0].result().result().at(0), res).value<TrainReservation>();
+            }
+        }
+    }
 
     // extract structured data from a pkpass, if the extractor script hasn't done so already
     switch (pass->type()) {
@@ -365,6 +472,14 @@ void PkPassDocumentProcessor::preExtract(ExtractorDocumentNode &node, [[maybe_un
                         res = flightRes;
                         break;
                     }
+                    case KPkPass::BoardingPass::Train:
+                    {
+                        auto trainRes = res.value<TrainReservation>();
+                        trainRes = extractTrainTicket(pass, trainRes);
+                        trainRes.setUnderName(extractPerson(pass, trainRes.underName().value<Person>()));
+                        res = trainRes;
+                        break;
+                    }
                     default:
                         if (!node.result().isEmpty()) { // don't overwrite better results from child nodes
                             return;
@@ -395,17 +510,17 @@ void PkPassDocumentProcessor::postExtract(ExtractorDocumentNode &node, [[maybe_u
     }
 
     // associate the pass with the result, so we can find the pass again for display
-    auto result = node.result().jsonLdResult();
-    for (auto resV : result) {
-        auto res = resV.toObject();
-        res.insert(QLatin1String("pkpassPassTypeIdentifier"), pass->passTypeIdentifier());
-        res.insert(QLatin1String("pkpassSerialNumber"), pass->serialNumber());
+    auto result = node.result().result();
+    for (auto &res : result) {
+        DocumentUtil::addDocumentId(res, DocumentUtil::idForPkPass(pass->passTypeIdentifier(), pass->serialNumber()));
+        // TODO replace this eventually with the more generic and standard compliant way above
+        JsonLdDocument::writeProperty(res, "pkpassPassTypeIdentifier", pass->passTypeIdentifier());
+        JsonLdDocument::writeProperty(res, "pkpassSerialNumber", pass->serialNumber());
         // pass->relevantDate() as modification time is inherently unreliable (it wont change most of the time)
         // so if we have something from an enclosing document, that's probably better
         if (node.parent().contextDateTime().isValid()) {
-            res.insert(QLatin1String("modifiedTime"),  node.parent().contextDateTime().toString(Qt::ISODate));
+            JsonLdDocument::writeProperty(res, "modifiedTime", node.parent().contextDateTime().toString(Qt::ISODate));
         }
-        resV = res;
     }
     node.setResult(result);
 }
