@@ -20,9 +20,20 @@ function parsePkPass(pass, node) {
     const addr = loc[1].match(/(.*), (.*?)$/);
     res.reservationFor.location.address.streetAddress = addr[1];
     res.reservationFor.location.address.addressLocality = addr[2];
-    res.reservedTicket.ticketedSeat.seatSection = pass.field['KEY_AUX_SEAT_2'].value;
-    res.reservedTicket.ticketedSeat.seatRow = pass.field['KEY_AUX_SEAT_3'].value;
-    res.reservedTicket.ticketedSeat.seatNumber = pass.field['KEY_AUX_SEAT_4'].value;
+
+    const seat2Field = pass.field['KEY_AUX_SEAT_2'];
+    if (seat2Field) {
+        res.reservedTicket.ticketedSeat.seatSection = seat2Field.value;
+    }
+    const seat3Field = pass.field['KEY_AUX_SEAT_3'];
+    if (seat3Field) {
+        res.reservedTicket.ticketedSeat.seatRow = seat3Field.value;
+    }
+    const seat4Field = pass.field['KEY_AUX_SEAT_4'];
+    if (seat4Field) {
+        res.reservedTicket.ticketedSeat.seatNumber = seat4Field.value;
+    }
+
     if (!res.reservedTicket.ticketedSeat.seatNumber) {
         res.reservedTicket.ticketedSeat.seatNumber = pass.field['KEY_BACK_SEATLINE'].value;
     }
